@@ -65,12 +65,14 @@ class SymProcessor:
 
         self.vars_dict = OrderedDict()
         self.vars_int_dict = OrderedDict()   # internal variables only
-        self.vars_list = list()
+        self.vars_list = list()       # list of variable symbols, corresponding to `self.xy`
         self.substitution_map = {}    # mapping of ``SubsService`` to its expression
 
         self.f_list, self.g_list = list(), list()  # symbolic equations in lists
         self.f_matrix, self.g_matrix, self.s_matrix = list(), list(), list()  # equations in matrices
-        self.s_syms = list()
+        self.s_syms = list()  # service symbols
+        self.j_args = dict()   # Jacobian name -> argument list
+        self.j_calls = dict()  # Jacobian name -> symbolic expressions
 
         # pretty print of variables
         self.xy = list()  # variables in the order of states, algebs
@@ -341,9 +343,9 @@ class SymProcessor:
         for idx, eq_sparse in enumerate(fg_sparse):
             for item in eq_sparse.row_list():
                 e_idx, v_idx, e_symbolic = item
-                if idx == 0:
+                if idx == 0:                              # differential equation
                     eq_name = states_and_ext_list[e_idx]
-                else:
+                else:                                     # algebraic equation
                     eq_name = algebs_and_ext_list[e_idx]
 
                 var_name = vars_syms_list[v_idx]
@@ -352,6 +354,7 @@ class SymProcessor:
                 jname = f'{eqn.e_code}{var.v_code}'
 
                 # jac calls with all arguments and stored individually
+                # the `0` value will be used for building the Jacobian sparsity pattern
                 self.calls.append_ijv(jname, e_idx, v_idx, 0)
 
                 # collect unique arguments for jac calls
@@ -361,6 +364,9 @@ class SymProcessor:
                         j_args[jname].append(fs)
                 j_calls[jname].append(e_symbolic)
 
+        self.j_args = j_args
+        self.j_calls = j_calls
+
         for jname in j_calls:
             # sort for stable argument list
             j_args[jname].sort(key=lambda s: s.name)
@@ -737,6 +743,43 @@ from andes.thirdparty.npfunc import *                               # NOQA
 
         return None
 
+    def get_var_symbol(self, xyname, *, with_ext=False):
+        """
+        Get a list of symbols for variables.
+
+        Parameters
+        ----------
+        xyname : str
+            'x' or 'y'
+        with_ext : bool
+            True to include external variables
+        """
+        if xyname not in ("x", "y"):
+            raise ValueError("unknown variable name %s" % xyname)
+
+        if len(self.vars_dict) == 0:
+            logger.warning("Symbols not generated. Trying to generate")
+            self.parent.prepare()
+
+        out = list()
+
+        if xyname == 'x':
+            if with_ext is True:
+                look_up_from = self.parent.cache.states_and_ext
+            else:
+                look_up_from = self.parent.states
+        else:
+            if with_ext is True:
+                look_up_from = self.parent.cache.algebs_and_ext
+            else:
+                look_up_from = self.parent.algebs
+
+        for name, sym in self.vars_dict.items():
+            if name in look_up_from:
+                out.append(sym)
+
+        return out
+
 
 def _store_deps(name, sympified, vars_int_dict, deps):
     """
