@@ -10,10 +10,85 @@ import re
 import numpy as np
 
 from andes.core.var import BaseVar
-from andes.shared import plt, set_font, set_latex
+from andes.shared import find_executable, mpl, plt
+from andes.utils.paths import get_dot_andes_path  # NOQA
 
 logger = logging.getLogger(__name__)
-DPI = 80
+DPI = None
+
+
+def set_latex():
+    """
+    Enables LaTeX for matplotlib based on the `with_latex` option and `dvipng` availability.
+
+    Returns
+    -------
+    bool
+        True for LaTeX on, False for off
+    """
+
+    if find_executable('dvipng'):
+        mpl.rc('text', usetex=True)
+
+        no_warn_file = os.path.join(get_dot_andes_path(), '.no_warn_latex')
+        if not os.path.isfile(no_warn_file):
+            print('Using LaTeX for rendering. If an error occurs:')
+            print('a) If you are using `andes plot`, disable with option "-d",')
+            print('b) If you are using `plot()`, set "latex=False".')
+
+            try:
+                with open(os.path.join(get_dot_andes_path(), '.no_warn_latex'), 'w') as f:
+                    f.write('0')
+            except OSError:
+                pass
+
+        return True
+
+    return False
+
+
+def set_font(family='serif', size=12, style='normal', weight='normal'):
+    """
+    Sets the font for matplotlib.
+
+    Parameters
+    ----------
+    family : str
+        Font family.
+    size : int
+        Font size.
+    style : str
+        Font style.
+    weight : str
+        Font weight.
+    """
+
+    mpl.rc('font', family=family, size=size, style=style, weight=weight)
+
+
+def set_style(style='default'):
+    """
+    Set matplotlib style.
+
+    Parameters
+    ----------
+    style : str
+        `default`, `ieee` (require `scienceplots`), or other available styles
+        (see `matplotlib.pyplot.style.available`).
+    """
+
+    if style is None:
+        style = 'default'
+
+    if style == 'ieee':
+        try:
+            plt.style.use(['science', 'ieee'])
+        except (NameError, OSError):
+            logger.error("Please install `scienceplots` with `pip` to use the 'ieee' style.")
+
+    else:
+        plt.style.use(style)
+        set_font()
 
 
 class TDSData:
@@ -55,6 +130,12 @@ class TDSData:
         self._process_names()
 
     def _process_names(self):
+        """
+        Helper function to process the file names.
+
+        Use "Untitled" if name is not set for case file.
+        """
+
         if self.full_name is None:
             logger.info("Input file name not detected. Using `Untitled`.")
             self.full_name = 'Untitled'
@@ -73,21 +154,32 @@ class TDSData:
         self._csv_file = os.path.join(self._path, self.file_name + '.csv')
 
     def load_dae(self):
-        """Load from DAE time series"""
-        dae = self.dae
-        self.t = dae.ts.t
-        self.nvars = dae.n + dae.m + dae.o + 1
+        """
+        Load from DAE time series.
+        """
 
+        dae = self.dae
+        system = self.dae.system
+
+        self.t = dae.ts.t
+
+        if system.Output.n == 0:
+            self.nvars = dae.n + dae.m + dae.o + 1
+        else:
+            self.nvars = len(system.Output.xidx) + len(system.Output.yidx) + dae.o + 1
+
+        self._uname = ['Time [s]'] + dae.x_name_output + dae.y_name_output + dae.z_name
+        self._fname = ['Time [s]'] + dae.x_tex_name_output + dae.y_tex_name_output + dae.z_tex_name
         self._idx = list(range(self.nvars))
-        self._uname = ['Time [s]'] + dae.x_name + dae.y_name + dae.z_name
-        self._fname = ['Time [s]'] + dae.x_tex_name + dae.y_tex_name + dae.z_tex_name
-        self._data = dae.ts.txyz
 
         if dae.system.files.lst is not None:
             self.full_name = dae.system.files.lst
         else:
             self.full_name = dae.system.files.case
 
+        if len(self.t) > 0:
+            self._data = dae.ts.txyz
+
     def load_lst(self):
         """
         Load the lst file into internal data structures `_idx`, `_fname`, `_uname`, and counts the number of
@@ -243,7 +335,13 @@ class TDSData:
             Sort by idx or not, # TODO: implement sort
         fmt : str
             cell formatter
+
+        Returns
+        -------
+        str
+            The path of the exported csv file
         """
+
         if not path:
             path = self._csv_file
         if not idx:
@@ -262,6 +360,8 @@ class TDSData:
 
         logger.info(f'CSV data saved to "{path}".')
 
+        return path
+
     def _process_yidx(self, yidx, a):
         """
         Helper function for processing ``yidx`` if it is a ``BaseVar`` or a list
@@ -269,21 +369,39 @@ class TDSData:
 
         Indexing by ``a`` is considered.
         """
+
+        dae = self.dae
+        system = self.dae.system
+
         if isinstance(yidx, BaseVar):
             yidx = [yidx]
 
         if isinstance(yidx, list) and isinstance(yidx[0], BaseVar):
             all_yidx = np.array([], dtype=int)
+
             for item in yidx:
                 if item.n == 0:
-                    logger.warning("Variable <%s> contains no values, ignored.", item.name)
+                    logger.info("Parent model <%s> of variable <%s> contains no device, ignored.",
+                                item.owner.class_name, item.name)
                     continue
-                if item.v_code == 'y':
-                    offs = self.dae.n + 1
-                else:
-                    offs = 1
 
-                new_yidx = item.a + offs
+                if system.Output.n > 0:
+                    output_addr = system.Output.to_output_addr(item, check=True)
+                    if len(output_addr) == 0:
+                        continue
+
+                    nx = len(system.Output.xidx)
+                else:
+                    output_addr = item.a
+                    nx = dae.n
+
+                # states are offset by 1 for Time. Algebs are offset by 1 + nx
+                if item.v_code == 'y':
+                    offset = nx + 1
+                else:
+                    offset = 1
+
+                new_yidx = output_addr + offset
 
                 if a is not None:
                     new_yidx = np.take(new_yidx, a)
@@ -291,6 +409,9 @@ class TDSData:
 
             yidx = all_yidx
 
+        elif isinstance(yidx, int):
+            yidx = [yidx]
+
         # a list of integers will remain unchanged
 
         return yidx
@@ -508,7 +629,7 @@ class TDSData:
                   hline1=None, hline2=None, vline1=None, hline=None, vline=None,
                   vline2=None, set_xlim=True, set_ylim=True, autoscale=False, figsize=None,
                   legend_bbox=None, legend_loc=None, legend_ncol=1,
-                  mask=True, color=None,
+                  mask=True, color=None, style='default',
                   **kwargs):
         """
         Plot lines for the supplied data and options.
@@ -549,7 +670,8 @@ class TDSData:
         >>>                      ylabel='Ipcmd [pu]')
 
         """
-        set_font(family='serif', size=font_size)
+
+        set_style(style)
 
         if not isinstance(ydata, np.ndarray):
             raise TypeError("ydata must be a numpy array. Retrieve with get_values().")
@@ -723,8 +845,8 @@ class TDSData:
 
         nyidxes = len(yidxes)
         if nyidxes > nrows * ncols:
-            raise ValueError("yidxes with length %d does not fit nrows=%d and ncols=%d",
-                             nyidxes, nrows, ncols)
+            raise ValueError("yidxes with length %d does not fit nrows=%d and ncols=%d" %
+                             (nyidxes, nrows, ncols))
 
         fig = plt.figure(figsize=figsize, dpi=dpi)
 
@@ -770,7 +892,7 @@ class TDSData:
 
         return fig, axes
 
-    def panoview(self, mdl, *, ncols=3, vars=None, idx=None, a=None, figsize=None, **kwargs):
+    def panoview(self, mdl, vars, *, ncols=3, idx=None, a=None, figsize=None, **kwargs):
         """
         Panoramic view of variables of a given model instance.
 
@@ -783,10 +905,10 @@ class TDSData:
         ----------
         mdl : ModelBase
             Model instance
-        ncol : int
-            Number of columns
         var : list of str
             A list of variable names to display
+        ncol : int
+            Number of columns
         idx : list
             A list of device idx-es for showing
         a : list of int
@@ -1007,23 +1129,29 @@ def tdsplot(filename, y, x=(0,),
     if len(filename) == 1:
         tds_data = TDSData(filename[0])
         if to_csv is True:
-            tds_data.export_csv()
-            return
+            return tds_data.export_csv()
+
         if find is not None:
             out = tds_data.find(query=find, exclude=exclude)
             print(out)
-            return
+            return out
+
         if xargs is not None:
             out = tds_data.find(query=xargs, exclude=exclude, idx_only=True)
             out = [str(i) for i in out]
-            print(filename[0] + ' 0 ' + ' '.join(out))
-            return
+            xargs_out = filename[0] + ' 0 ' + ' '.join(out)
+            print(xargs_out)
+            return xargs_out
+
         if len(y) == 0:
             logger.error('Must specify Y indices to plot.')
-            return
+            return tds_data
+
         y_num = parse_y(y, lower=0, upper=tds_data.nvars)
         tds_data.plot(xidx=x, yidx=y_num, **kwargs)
+
         return tds_data
+
     else:
         raise NotImplementedError("Plotting multiple data files are not supported yet")
 
