@@ -4,8 +4,12 @@ import andes
 
 
 class TestCodegen(unittest.TestCase):
+    """
+    Test code generation.
+    """
+
     def test_1_docs(self) -> None:
-        self.ss = andes.main.prepare(quick=True)
+        ss = andes.main.prepare(quick=True)
         out = ''
-        for group in self.ss.groups.values():
+        for group in ss.groups.values():
             out += group.doc_all()
